@@ -17,7 +17,10 @@ interface to a small ASCII data file, so who needs lots of classes?
 
 Examples:
 
->>> tbl = pypdt.ParticleDataTable('particle.tbl')
+>>> import pypdt
+>>> pypdt.get(2212) # print out proton particle data
+>>> p = pypdt.get(2112) # get the neutron particle data object
+>>> tbl = pypdt.ParticleDataTable() # make a particle data table
 >>> # or tbl = pypdt.ParticleDataTable() # to read from AFS default db
 >>> # or tbl = pypdt.PDT() # if you prefer minimal keystrokes to clarity :)
 >>> print tbl[13] # print a summary of muon information
@@ -59,7 +62,7 @@ TODO:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch>"
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 
 from .pdt import *
 from .pid import *
